Crate rexlang_core

Crate rexlang_core 

Re-exports

pub use crate::json::EnumPatch;
pub use crate::json::JsonOptions;
pub use crate::json::json_to_rex;
pub use crate::json::rex_to_json;

Modules

json

Macros

assert_pointer_eq

Structs

AdtConflict
AdtDecl
A type declaration for an algebraic data type.
CollectAdtsError
Engine
EngineOptions
Export
GasCosts
GasMeter
Heap
Module
Parser
ParserErr
ParserLimits
Pointer
Program
Scheme
Type
TypeSystem
ValueDisplayOptions

Enums

BuiltinTypeId
EngineError
PreludeMode
Token
A Token represents a lexical token in the Rex programming language. It includes the values of literals, identifiers, and comments.
TypeError
TypeKind
Value

Constants

PRELUDE_MODULE_NAME
ROOT_MODULE_NAME

Traits

AsyncHandler
FromPointer
Handler
IntoPointer
RexAdt
Shared ADT registration surface for derived and manually implemented Rust types.
RexDefault
RexType

Functions

closure_debug
closure_eq
collect_adts_error_to_engine
Convert ADT collection conflicts into an embedder-facing EngineError.
collect_adts_in_types
Collect all user-defined ADT constructors referenced by the provided types.
intern
pointer_display
pointer_display_with
sym
value_debug
value_eq

Type Aliases

AsyncNativeCallable
AsyncNativeCallableCancellable
NativeFuture
SyncNativeCallable

Derive Macros

Rex